# 完成

实验已成功完成

- 时间: `%(time)s`
- 日志文件: `%(logfile)s`

你可以:

[打开日志文件](opensesame://event.after_experiment_open_logfile){: .important-button}<br />
[打开日志文件夹](opensesame://event.after_experiment_open_logfile_folder){: .button}<br />
[将日志文件复制到文件池](opensesame://event.after_experiment_copy_logfile){: .button}
